Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaurício Meneghini Fauth <mauriciofauth@gmail.com>2018-08-29 06:43:39 +0300
committerMaurício Meneghini Fauth <mauriciofauth@gmail.com>2018-11-11 01:48:59 +0300
commite7e7d56c759366c61824b67f48ec0ba4d5507105 (patch)
treece4e0f363bfb90b31813512917f011a998ad20a6 /browse_foreigners.php
parent88e162b651dfbd64c98ac40976023c4b7d1438bb (diff)
Retrieve parameters from $_POST in browse foreigners
Signed-off-by: Maurício Meneghini Fauth <mauriciofauth@gmail.com>
Diffstat (limited to 'browse_foreigners.php')
-rw-r--r--browse_foreigners.php16
1 files changed, 8 insertions, 8 deletions
diff --git a/browse_foreigners.php b/browse_foreigners.php
index 0ae36334d1..f3c3fab41b 100644
--- a/browse_foreigners.php
+++ b/browse_foreigners.php
@@ -14,7 +14,7 @@ use PhpMyAdmin\Util;
require_once 'libraries/common.inc.php';
/**
* Sets globals from $_REQUEST
*/
$request_params = array(
'data',
@@ -22,8 +22,8 @@ $request_params = array(
);
foreach ($request_params as $one_request_param) {
- if (isset($_REQUEST[$one_request_param])) {
- $GLOBALS[$one_request_param] = $_REQUEST[$one_request_param];
+ if (isset($_POST[$one_request_param])) {
+ $GLOBALS[$one_request_param] = $_POST[$one_request_param];
}
}
@@ -49,13 +49,13 @@ $browseForeigners = new BrowseForeigners(
$GLOBALS['pmaThemeImage']
);
$foreign_limit = $browseForeigners->getForeignLimit(
- isset($_REQUEST['foreign_showAll']) ? $_REQUEST['foreign_showAll'] : null
+ isset($_POST['foreign_showAll']) ? $_POST['foreign_showAll'] : null
);
$foreignData = $relation->getForeignData(
- $foreigners, $_REQUEST['field'], true,
- isset($_REQUEST['foreign_filter'])
- ? $_REQUEST['foreign_filter']
+ $foreigners, $_POST['field'], true,
+ isset($_POST['foreign_filter'])
+ ? $_POST['foreign_filter']
: '',
isset($foreign_limit) ? $foreign_limit : null,
true // for getting value in $foreignData['the_total']
@@ -65,7 +65,7 @@ $foreignData = $relation->getForeignData(
$html = $browseForeigners->getHtmlForRelationalFieldSelection(
$db,
$table,
- $_REQUEST['field'],
+ $_POST['field'],
$foreignData,
isset($fieldkey) ? $fieldkey : null,
isset($data) ? $data : null
@@ -14,7 +14,7 @@ use PhpMyAdmin\Util;
require_once 'libraries/common.inc.php';
/**
- * Sets globals from $_REQUEST
+ * Sets globals from $_POST
*/
$request_params = array(